@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -21,7 +21,7 @@ import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
 import EditorTools from '..';
 
-jest.mock('../../../contexts/ToggleBars');
+jest.mock('@/contexts/ToggleBars');
 
 const mockClipboard = jest.fn();
 jest.mock('react-copy-to-clipboard', () => {
