@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -372,7 +372,7 @@ class Progress extends React.Component<Props, State> {
     const { history, searchParams } = this.props;
     const { factoryParams } = this.state;
 
-    const usePrebuiltResources = factoryParams.useDevworkspaceResources;
+    const usePrebuiltResources = factoryParams.useDevWorkspaceResources;
     const steps = [
       usePrebuiltResources ? this.getFactoryFetchResources() : this.getFactoryFetchDevfile(),
       this.getCheckExistingWorkspacesStep(),
