@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -27,7 +27,7 @@ import WorkspaceDetailsContainer from '..';
 
 const mockUpdateWorkspace = jest.fn();
 
-jest.mock('../../../store/Workspaces');
+jest.mock('@/store/Workspaces');
 (workspacesActionCreators.requestWorkspaces as jest.Mock).mockImplementation(() => async () => {
   // no-op
 });
@@ -37,7 +37,7 @@ jest.mock('../../../store/Workspaces');
       mockUpdateWorkspace(...args),
 );
 
-jest.mock('../../../pages/WorkspaceDetails');
+jest.mock('@/pages/WorkspaceDetails');
 
 describe('Workspace Details container', () => {
   const namespace = 'user-dev';
