@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -44,7 +44,7 @@ const mockRequestTokens = jest.fn();
 const mockAddToken = jest.fn();
 const mockUpdateToken = jest.fn();
 const mockRemoveToken = jest.fn();
-jest.mock('../../../../store/PersonalAccessToken', () => ({
+jest.mock('@/store/PersonalAccessToken', () => ({
   actionCreators: {
     addToken:
       (...args): AppThunk<Action, Promise<void>> =>
