@@ -31,8 +31,12 @@ export interface AlertItem {
   timeout?: boolean | number;
 }
 
+// Field `source` tells where devfile comes from
+//  - no source: the url to raw content is used
+//  - "repo": means no devfile is found and default is generated
+//  - any other - devfile is found in repository as filename from the value
 export interface FactoryResolver extends Omit<che.api.factory.Factory, 'devfile'> {
-  devfile: che.api.workspace.devfile.Devfile | devfileApi.Devfile;
+  devfile?: che.api.workspace.devfile.Devfile | devfileApi.Devfile;
   location?: string;
   scm_info?: FactoryResolverScmInfo;
 }
@@ -75,8 +79,6 @@ export function isDevWorkspaceStatus(status: unknown): status is DevWorkspaceSta
   return Object.values(DevWorkspaceStatus).includes(status as DevWorkspaceStatus);
 }
 
-export type CreateWorkspaceTab = 'quick-add' | 'custom-workspace';
-
 export enum LoaderTab {
   Progress = 'Progress',
   Logs = 'Logs',
@@ -91,15 +93,12 @@ export enum WorkspaceDetailsTab {
 }
 
 export enum WorkspaceAction {
+  DELETE_WORKSPACE = 'Delete Workspace',
   OPEN_IDE = 'Open',
+  RESTART_WORKSPACE = 'Restart Workspace',
   START_DEBUG_AND_OPEN_LOGS = 'Open in Debug mode',
   START_IN_BACKGROUND = 'Start in background',
   STOP_WORKSPACE = 'Stop Workspace',
-  DELETE_WORKSPACE = 'Delete Workspace',
-  ADD_PROJECT = 'Add Project',
-  ADD_CUSTOM_WORKSPACE = 'Add Workspace',
-  RESTART_WORKSPACE = 'Restart Workspace',
-  WORKSPACE_DETAILS = 'Workspace Details',
 }
 
 export enum UserPreferencesTab {
