@@ -25,15 +25,15 @@ export interface Plugin {
   id: string;
   name: string;
   publisher: string;
-  deprecate?: {
-    automigrate: boolean;
-    migrateTo: string;
-  };
-  displayName: string;
+  displayName?: string;
   type: string;
-  version?: string;
+  version: string;
   description?: string;
-  isEnabled?: boolean;
+  links: {
+    devfile: string;
+  };
+  icon: string;
+  tags?: string[];
 }
 
 export interface WorkspaceDevfileAttributes {
