@@ -23,11 +23,7 @@ import mockThunk from '@/store/__mocks__/thunk';
 import { State as BrandingState } from '@/store/Branding';
 import { DevWorkspaceResources, State as DevfileRegistriesState } from '@/store/DevfileRegistries';
 import { RegistryEntry } from '@/store/DockerConfig/types';
-import {
-  ConvertedState,
-  ResolverState,
-  State as FactoryResolverState,
-} from '@/store/FactoryResolver';
+import { FactoryResolverState, FactoryResolverStateResolver } from '@/store/FactoryResolver';
 import { IGitOauth } from '@/store/GitOauthConfig/types';
 import { State as InfrastructureNamespaceState } from '@/store/InfrastructureNamespaces';
 import { State as PluginsState } from '@/store/Plugins/chePlugins';
@@ -262,21 +258,18 @@ export class FakeStoreBuilder {
 
   public withFactoryResolver(
     options: {
-      resolver?: Partial<ResolverState>;
-      converted?: Partial<ConvertedState>;
+      resolver?: Partial<FactoryResolverStateResolver>;
     },
     isLoading = false,
   ): FakeStoreBuilder {
     if (options.resolver) {
-      this.state.factoryResolver.resolver = Object.assign({}, options.resolver as ResolverState);
+      this.state.factoryResolver.resolver = Object.assign(
+        {},
+        options.resolver as FactoryResolverStateResolver,
+      );
     } else {
       delete this.state.factoryResolver.resolver;
     }
-    if (options.converted) {
-      this.state.factoryResolver.converted = Object.assign({}, options.converted as ConvertedState);
-    } else {
-      delete this.state.factoryResolver.converted;
-    }
     this.state.factoryResolver.isLoading = isLoading;
     return this;
   }
@@ -312,7 +305,7 @@ export class FakeStoreBuilder {
       devWorkspaceResources?: {
         [location: string]: { resources?: DevWorkspaceResources; error?: string };
       };
-      schema?: any;
+      filter?: string;
     },
     isLoading = false,
   ): FakeStoreBuilder {
@@ -328,6 +321,9 @@ export class FakeStoreBuilder {
         options.devWorkspaceResources,
       );
     }
+    if (options.filter) {
+      this.state.devfileRegistries.filter = options.filter;
+    }
     this.state.devfileRegistries.isLoading = isLoading;
     return this;
   }
